tendril.utils.files package
===========================

Submodules
----------

.. toctree::

   tendril.utils.files.libreoffice
   tendril.utils.files.markdown
   tendril.utils.files.pdf
   tendril.utils.files.yml

Module contents
---------------

.. automodule:: tendril.utils.files
    :members:
    :undoc-members:
    :show-inheritance:
